"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prismjs_1 = __importDefault(require("prismjs"));
const lodash_1 = __importDefault(require("lodash"));
const index_1 = __importDefault(require("prismjs/components/index"));
const components_1 = require("prismjs/components");
const directives_1 = require("./directives");
const unsupportedLanguages = new Set();
function highlightCode(language, code, lineNumbersHighlight = []) {
    const lang = language.toLowerCase();
    if (lang === "none") {
        return code;
    }
    if (lang === "text" || unsupportedLanguages.has(lang)) {
        return lodash_1.default.escape(code);
    }
    // (Try to) load languages on demand.
    if (!prismjs_1.default.languages[lang]) {
        try {
            index_1.default([lang]);
        }
        catch (e) {
            // Language wasn't loaded so let's bail.
            console.log(e);
            const message = `unable to find prism language '${language}' for highlighting.`;
            if (!unsupportedLanguages.has(lang)) {
                console.warn(message, "applying generic code block");
                unsupportedLanguages.add(lang);
            }
            return lodash_1.default.escape(code);
        }
    }
    const grammar = prismjs_1.default.languages[lang];
    if (!grammar) {
        return code;
    }
    const highlighted = prismjs_1.default.highlight(code, grammar, lang);
    const codeSplits = directives_1.handleDirectives(highlighted, lineNumbersHighlight);
    let finalCode = "";
    const lastIdx = codeSplits.length - 1;
    // Don't add back the new line character after highlighted lines
    // as they need to be display: block and full-width.
    codeSplits.forEach((split, idx) => {
        finalCode += split.highlight
            ? split.code
            : `${split.code}${idx === lastIdx ? "" : "\n"}`;
    });
    return finalCode;
}
exports.highlightCode = highlightCode;
const grammarMap = {};
lodash_1.default.forEach(components_1.languages, (g, lang) => {
    if (lang === "meta") {
        return;
    }
    const grammar = Object.assign({}, g, { lang });
    grammarMap[lang] = grammar;
    const { alias } = grammar;
    if (!alias) {
        return;
    }
    if (lodash_1.default.isArray(alias)) {
        alias.forEach(a => {
            grammarMap[a] = grammar;
        });
    }
    else {
        grammarMap[alias] = grammar;
    }
});
function getTitle(name) {
    const lang = name.toLowerCase();
    if (unsupportedLanguages.has(lang)) {
        return null;
    }
    if (!(lang in grammarMap)) {
        unsupportedLanguages.add(lang);
        return null;
    }
    const { title, aliasTitles = {} } = grammarMap[lang];
    const aliasTitle = aliasTitles[lang];
    return aliasTitle ? aliasTitle : title;
}
exports.getTitle = getTitle;
function getName(name) {
    const lang = name.toLowerCase();
    if (unsupportedLanguages.has(lang)) {
        return name;
    }
    if (!(lang in grammarMap)) {
        unsupportedLanguages.add(lang);
        return name;
    }
    return grammarMap[lang].lang;
}
exports.getName = getName;
//# sourceMappingURL=highlightCode.js.map