"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const parse_numeric_range_1 = __importDefault(require("parse-numeric-range"));
const lodash_1 = __importDefault(require("lodash"));
function parseLineNumber(option) {
    const options = option.split(":");
    if (options.length !== 2) {
        return {};
    }
    const [key, valueStr] = options;
    const trimValue = valueStr.trim();
    let numberLinesStartAt = -1;
    if (trimValue === "true") {
        numberLinesStartAt = 1;
    }
    else {
        const valueNum = lodash_1.default.parseInt(trimValue);
        if (lodash_1.default.isSafeInteger(valueNum) && valueNum > 0) {
            numberLinesStartAt = valueNum;
        }
    }
    if (key !== "numberLines" || numberLinesStartAt < 1) {
        return {};
    }
    return { showLineNumbersLocal: true, numberLinesStartAt };
}
function parseLineNumberRange(language) {
    if (!language) {
        return {};
    }
    if (language.split("{").length > 1) {
        let [splitLanguage, ...options] = language.split("{");
        // Options can be given in any order and are optional
        let range = { splitLanguage, highlightLines: [] };
        options.forEach(lineOption => {
            let option = lineOption.slice(0, -1);
            // Test if the option is for line hightlighting
            if (parse_numeric_range_1.default.parse(option).length > 0) {
                range.highlightLines = parse_numeric_range_1.default.parse(option).filter(n => n > 0);
            }
            range = lodash_1.default.merge(range, parseLineNumber(option));
        });
        return range;
    }
    return { splitLanguage: language };
}
exports.parseLineNumberRange = parseLineNumberRange;
//# sourceMappingURL=parseLineNumberRange.js.map